/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   TrackingChain.h
/// \date   13.09.2023
/// \brief  A chain class to execute CA tracking algorithm in online reconstruction (header)
/// \author S.Zharko <s.zharko@gsi.de>

#ifndef CBM_ALGO_CA_TRACKING_CHAIN
#define CBM_ALGO_CA_TRACKING_CHAIN 1

#include <vector>

#include "CaTrack.h"
#include "SubChain.h"

namespace cbm::algo::ca
{
  /// \enum  cbm::algo::ca::EDetectorID
  /// \brief Enumeration for the detector subsystems used in CBM online tracking
  /// \note  It is important, that the subsystems are specified in the actual order.
  /// \note  The enumeration must not contain jumps in the ordering and the first entry must be equal 0
  enum class EDetectorID
  {
    Mvd = 0,
    Sts,
    Much,
    Trd,
    Tof,
    kEND  ///< End of enumeration
  };
}  // namespace cbm::algo::ca

namespace cbm::algo
{
  /// \class cbm::algo::TrackingChain
  /// \brief A chain for tracking algorithm
  ///
  /// The class executes a tracking algorithm in the online data reconstruction chain.
  class TrackingChain : public SubChain {
  public:
    /// @brief  Provides action in the initialization of the run
    void Init();

    /// @brief  Provides action for a given time-slice
    /// @return A vector of cbm::algo::ca::Track
    std::vector<ca::Track> Run(/*vecotrs of hits*/);

    /// @brief  Provides action in the end of the run
    void Finalize();
  };
}  // namespace cbm::algo

#endif  // CBM_ALGO_CA_TRACKING_CHAIN
