/* Copyright (C) 2010-2021 Frankfurt Institute for Advanced Studies, Goethe-Universität Frankfurt, Frankfurt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Maksym Zyzak, Igor Kulakov [committer], Sergey Gorbunov */

/// \file CaDefines.h
/// \brief Macros for the CA tracking algorithm
/// \details Try to minimize the amount of macros. Try to call this header only from cxx files.

#pragma once  // include this header only once per compilation unit

#include <iostream>

#include <assert.h>

// #define CBMCA_DEBUG_MODE

#if defined(CBMCA_DEBUG_MODE)

#define CBMCA_DEBUG_ASSERT(v)                                                                                          \
  if (!(v)) {                                                                                                          \
    std::cerr << __FILE__ << ":" << __LINE__ << " assertion failed: " << #v << " = " << (v) << std::endl;              \
    assert(v);                                                                                                         \
  }

#define CBMCA_DEBUG_SHOW(expr)                                                                                         \
  std::cout << __FILE__ << ":" << __LINE__ << ": \033[01;38;5;208m" << (#expr) << "\033[0m = " << (expr) << "\n"

#define CBMCA_DEBUG_SHOWF(msg)                                                                                         \
  std::cout << "(!) " << __FILE__ << ":" << __LINE__ << ": \033[01;38;5;208m" << (#msg) << "\033[0m\n"

#define CBMCA_DEBUG_SHOWCONTAINER(cont)                                                                                \
  std::cout << __FILE__ << ":" << __LINE__ << ": \033[01;38;5;208m" << (#cont) << "\033[0m: ";                         \
  std::for_each(cont.cbegin(), cont.cend(), [](const auto& el) { std::cout << el << ' '; });                           \
  std::cout << '\n';

#else  // not CBMCA_DEBUG_MODE

#define CBMCA_DEBUG_ASSERT(v)

#define CBMCA_DEBUG_SHOW(expr)

#define CBMCA_DEBUG_SHOWF(msg)

#define CBMCA_DEBUG_SHOWCONTAINER(cont)

#endif  // CBMCA_DEBUG_MODE
