/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   CaTrackingMonitor.h
/// \brief  Monitor specification for the tracking algorithm
/// \since  19.10.2023
/// \author S.Zharko <s.zharko@gsi.de>

#pragma once

#include "CaMonitor.h"

namespace cbm::algo::ca
{
  /// \enum  ECounter
  /// \brief Counter keys for the CA algo monitor
  enum class ECounter
  {
    RecoTrack,    ///< number of reconstructed tracks
    RecoHit,      ///< number of reconstructed hits
    RecoHitUsed,  ///< number of used reconstructed hits
    Triplet,      ///< number of triplets
    SubTS,        ///< number of sub time-slices
    kEND
  };

  /// \enum  ETimer
  /// \brief Timer keys for the CA algo monitor
  enum class ETimer
  {
    Tracking,
    TrackFinder,
    TrackFitter,
    TripletConstruction,
    NeighboringTripletSearch,
    kEND
  };

  using TrackingMonitor     = Monitor<ECounter, ETimer>;
  using TrackingMonitorData = MonitorData<ECounter, ETimer>;
}  // namespace cbm::algo::ca
