/* Copyright (C) 2023 FIAS Frankfurt Institute for Advanced Studies, Frankfurt / Main
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Felix Weiglhofer [committer] */
#ifndef CBM_ALGO_GLOBAL_STORABLE_RECO_RESULTS_H
#define CBM_ALGO_GLOBAL_STORABLE_RECO_RESULTS_H

#include "CbmDigiEvent.h"

#include <boost/serialization/access.hpp>
#include <boost/serialization/vector.hpp>

#include <cstdint>

namespace cbm::algo
{

  class StorableRecoResults {

  public:
    /**
     * @brief Default constructor (required by boost::serialization)
     */
    StorableRecoResults() = default;

    StorableRecoResults(uint64_t tsIndex, uint64_t tsStartTime) : fTsIndex(tsIndex), fTsStartTime(tsStartTime) {}

    /**
     * @brief Index of the timeslice during the run
     */
    uint64_t TsIndex() const { return fTsIndex; }

    /**
     * @brief Start time of the timeslice
     */
    uint64_t TsStartTime() const { return fTsStartTime; }

    std::vector<CbmDigiEvent>& DigiEvents() { return fDigiEvents; }
    const std::vector<CbmDigiEvent>& DigiEvents() const { return fDigiEvents; }

    PartitionedVector<sts::Hit>& StsHits() { return fStsHits; }
    const PartitionedVector<sts::Hit>& StsHits() const { return fStsHits; }

  private:
    uint64_t fTsIndex     = UINT64_MAX;
    uint64_t fTsStartTime = UINT64_MAX;

    std::vector<CbmDigiEvent> fDigiEvents;
    PartitionedVector<sts::Hit> fStsHits;

    friend class boost::serialization::access;

    template<class Archive>
    void serialize(Archive& ar, unsigned int /*version*/)
    {
      ar& fTsIndex;
      ar& fTsStartTime;

      ar& fDigiEvents;
      ar& fStsHits;
    }
  };

}  // namespace cbm::algo

#endif  // CBM_ALGO_GLOBAL_STORABLE_RECO_RESULTS_H
