/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   CbmQaManager.h
/// \brief  Manager task for other QA taska (header)
/// \author Sergei Zharko <s.zharko@gsi.de>
/// \since  17.10.2023

#pragma once

#include "FairTask.h"

#include <map>
#include <string>

class CbmQaManager : public FairTask {
public:
  /// \brief  Constructor from parameters
  /// \param  verbose  Verbose level
  CbmQaManager(int verbose = 1);

  /// \brief  Destructor
  virtual ~CbmQaManager() = default;

  /// \brief Copy constructor
  CbmQaManager(const CbmQaManager&) = delete;

  /// \brief Move constructor
  CbmQaManager(CbmQaManager&&) = delete;

  /// \brief Copy assignment operator
  CbmQaManager& operator=(const CbmQaManager&) = delete;

  /// \brief Move assignment operator
  CbmQaManager& operator=(CbmQaManager&&) = delete;

  /// \brief Adds sub-task
  void AddTask(FairTask* task) { this->Add(task); }

  /// \brief Action of the task in the time-slice
  void Exec(Option_t*) {};

  /// \brief Action of the task in the end of the run
  void Finish();

  /// \brief Task initialization
  InitStatus Init();

  /// \brief Task re-initialization
  InitStatus ReInit() { return Init(); }

  ClassDef(CbmQaManager, 0);

  /// \brief Gets status flag
  bool GetStatus() const { return fStatus; }

private:
  bool fStatus = true;  ///< Status of QA: true - all tasks passed, false - at least one of the task failed
};
